@@ -1,4 +1,4 @@
-use std::io::{Write, Result as IoResult};
+use std::io::{self, Write};
 
 use ll;
 
@@ -22,7 +22,9 @@ impl Drop for EncoderContext {
 
 /// An encoder that compress and forward data to another writer.
 ///
-/// The zstd library has an internal input buffer (~128kb).
+/// Don't forget to call `finish()` before dropping it!
+///
+/// Note: The zstd library has its own internal input buffer (~128kb).
 pub struct Encoder<W: Write> {
     // output writer (compressed data)
     writer: W,
@@ -37,11 +39,13 @@ impl<W: Write> Encoder<W> {
     /// Creates a new encoder.
     ///
     /// `level`: compression level (1-21)
-    pub fn new(writer: W, level: i32) -> IoResult<Self> {
+    pub fn new(writer: W, level: i32) -> io::Result<Self> {
         let context = EncoderContext::new();
 
         // Initialize the stream
-        try!(ll::parse_code(unsafe { ll::ZBUFF_compressInit(context.c, level) }));
+        try!(ll::parse_code(unsafe {
+            ll::ZBUFF_compressInit(context.c, level)
+        }));
 
         Encoder::with_context(writer, context)
     }
@@ -50,7 +54,8 @@ impl<W: Write> Encoder<W> {
     ///
     /// (Provides better compression ratio for small files,
     /// but requires the dictionary to be present during decompression.)
-    pub fn with_dictionary(writer: W, level: i32, dictionary: &[u8]) -> IoResult<Self> {
+    pub fn with_dictionary(writer: W, level: i32, dictionary: &[u8])
+                           -> io::Result<Self> {
         let context = EncoderContext::new();
 
         // Initialize the stream with an existing dictionary
@@ -64,7 +69,7 @@ impl<W: Write> Encoder<W> {
         Encoder::with_context(writer, context)
     }
 
-    fn with_context(writer: W, context: EncoderContext) -> IoResult<Self> {
+    fn with_context(writer: W, context: EncoderContext) -> io::Result<Self> {
         // This is the output buffer size, for compressed data we get from zstd.
         let buffer_size = unsafe { ll::ZBUFF_recommendedCOutSize() };
 
@@ -75,15 +80,17 @@ impl<W: Write> Encoder<W> {
         })
     }
 
-    /// Finishes the stream. You need to call this after writing your stuff.
+    /// Finishes the stream. You *need* to call this after writing your stuff.
     ///
     /// This returns the inner writer in case you need it.
-    pub fn finish(mut self) -> IoResult<W> {
+    pub fn finish(mut self) -> io::Result<W> {
 
         // First, closes the stream.
         let mut out_size = self.buffer.capacity();
         let remaining = try!(ll::parse_code(unsafe {
-            ll::ZBUFF_compressEnd(self.context.c, self.buffer.as_mut_ptr(), &mut out_size)
+            ll::ZBUFF_compressEnd(self.context.c,
+                                  self.buffer.as_mut_ptr(),
+                                  &mut out_size)
         }));
         unsafe {
             self.buffer.set_len(out_size);
@@ -107,7 +114,7 @@ impl<W: Write> Encoder<W> {
 }
 
 impl<W: Write> Write for Encoder<W> {
-    fn write(&mut self, buf: &[u8]) -> IoResult<usize> {
+    fn write(&mut self, buf: &[u8]) -> io::Result<usize> {
         // How much we've read from this task
         let mut read = 0;
         while read != buf.len() {
@@ -117,7 +124,8 @@ impl<W: Write> Write for Encoder<W> {
             unsafe {
                 // Compress the given buffer into our output buffer
                 let code = ll::ZBUFF_compressContinue(self.context.c,
-                                                      self.buffer.as_mut_ptr(),
+                                                      self.buffer
+                                                          .as_mut_ptr(),
                                                       &mut out_size,
                                                       buf[read..].as_ptr(),
                                                       &mut in_size);
@@ -132,10 +140,12 @@ impl<W: Write> Write for Encoder<W> {
         Ok(read)
     }
 
-    fn flush(&mut self) -> IoResult<()> {
+    fn flush(&mut self) -> io::Result<()> {
         let mut out_size = self.buffer.capacity();
         let written = try!(ll::parse_code(unsafe {
-            ll::ZBUFF_compressFlush(self.context.c, self.buffer.as_mut_ptr(), &mut out_size)
+            ll::ZBUFF_compressFlush(self.context.c,
+                                    self.buffer.as_mut_ptr(),
+                                    &mut out_size)
         }));
         unsafe {
             self.buffer.set_len(written);
